@@ -26,6 +26,7 @@ MainWindow::MainWindow (QWidget *parent)
 , pSystray (NULL)
 , pContactsView (NULL)
 , pInboxView (NULL)
+, pWebWidget (new WebWidget (this, Qt::Window))
 , bLoggedIn (false)
 , mtxDial (QMutex::Recursive)
 , bCallInProgress (false)
@@ -57,6 +58,9 @@ MainWindow::MainWindow (QWidget *parent)
     }
 #endif
 
+    pWebWidget->hide ();
+    osd.setDefaultWindowAttributes (pWebWidget);
+
     fDialpad_Style.setFileName (strDialpadFile);
     if (fDialpad_Style.open (QIODevice::ReadOnly)) {
         ui->wgtDialpad->setStyleSheet (fDialpad_Style.readAll ());
@@ -114,7 +118,7 @@ MainWindow::log (const QString &strText, int level /*= 10*/)
 void
 MainWindow::setStatus(const QString &strText, int timeout /* = 0*/)
 {
-//    log (strText);
+    qDebug () << strText;
     ui->statusBar->showMessage (strText, timeout);
 }//MainWindow::setStatus
 
@@ -149,34 +153,25 @@ MainWindow::init ()
          this   , SLOT   (dialAccessNumber (const QString &,
                                             const QVariant &)));
 
-    // Skype client factory log and status
+    // Skype client factory main widget and status
     SkypeClientFactory &skypeFactory = Singletons::getRef().getSkypeFactory ();
     skypeFactory.setMainWidget (this);
-    QObject::connect (
-        &skypeFactory, SIGNAL (log(const QString &, int)),
-         this        , SLOT   (log(const QString &, int)));
     QObject::connect (
         &skypeFactory, SIGNAL (status(const QString &, int)),
          this        , SLOT   (setStatus(const QString &, int)));
 
-    // Observer factory log and status
+    // Observer factory init and status
     ObserverFactory &obF = Singletons::getRef().getObserverFactory ();
     obF.init ();
-    QObject::connect (&obF , SIGNAL (log(const QString &, int)),
-                       this, SLOT   (log(const QString &, int)));
     QObject::connect (&obF , SIGNAL (status(const QString &, int)),
                        this, SLOT   (setStatus(const QString &, int)));
 
-    // webPage log and status
-    QObject::connect (&webPage, SIGNAL (log(const QString &, int)),
-                       this   , SLOT   (log(const QString &, int)));
+    // webPage init and status
     QObject::connect (&webPage, SIGNAL (status(const QString &, int)),
                        this   , SLOT   (setStatus(const QString &, int)));
 
-    // call initiator log status and init
+    // call initiator init and status
     CallInitiatorFactory& cif = Singletons::getRef().getCIFactory ();
-    QObject::connect (&cif , SIGNAL (log(const QString &, int)),
-                       this, SLOT   (log(const QString &, int)));
     QObject::connect (&cif , SIGNAL (status(const QString &, int)),
                        this, SLOT   (setStatus(const QString &, int)));
 
@@ -194,7 +189,7 @@ MainWindow::init ()
     }
     else
     {
-        setStatus ("No user credentials cached. Please log in");
+        setStatus ("No user credentials cached. Please login");
 
         strUser.clear ();
         strPass.clear ();
@@ -220,7 +215,7 @@ MainWindow::doLogin ()
         if (!webPage.enqueueWork (GVAW_login, l, this,
                 SLOT (loginCompleted (bool, const QVariantList &))))
         {
-            log ("Login returned immediately with failure!", 3);
+            qWarning ("Login returned immediately with failure!");
             break;
         }
 
@@ -328,27 +323,9 @@ MainWindow::orientationChanged ()
     if (screenGeometry.width() > screenGeometry.height()) {
         ui->gridMain->removeWidget (ui->wgtDialpad);
         ui->gridMain->addWidget (ui->wgtDialpad, 0, 1);
-
-#if 0//def Q_WS_MAEMO_5
-        if (NULL != pContactsView) {
-            pContactsView->setAttribute (Qt::WA_Maemo5LandscapeOrientation);
-        }
-        if (NULL != pInboxView) {
-            pInboxView->setAttribute (Qt::WA_Maemo5LandscapeOrientation);
-        }
-#endif
     } else {
         ui->gridMain->removeWidget (ui->wgtDialpad);
         ui->gridMain->addWidget (ui->wgtDialpad, 1, 0);
-
-#if 0 //def Q_WS_MAEMO_5
-        if (NULL != pContactsView) {
-            pContactsView->setAttribute (Qt::WA_Maemo5PortraitOrientation);
-        }
-        if (NULL != pInboxView) {
-            pInboxView->setAttribute (Qt::WA_Maemo5PortraitOrientation);
-        }
-#endif
     }
 }//MainWindow::orientationChanged
 
@@ -459,17 +436,14 @@ MainWindow::initContactsWidget ()
 {
     do { // Begin cleanup block (not a loop)
         if (NULL != pContactsView) {
-            log ("Contacts widget is already active");
+            qDebug ("Contacts widget is already active");
             break;
         }
 
         // Create the contact view
         pContactsView = new GVContactsTable (this);
 
-        // Log and status
-        QObject::connect (
-            pContactsView, SIGNAL (log(const QString &, int)),
-            this         , SLOT   (log(const QString &, int)));
+        // Status
         QObject::connect (
             pContactsView, SIGNAL (status   (const QString &, int)),
             this         , SLOT   (setStatus(const QString &, int)));
@@ -505,7 +479,7 @@ MainWindow::deinitContactsWidget ()
 {
     do { // Begin cleanup block (not a loop)
         if (NULL == pContactsView) {
-            log ("Contacts widget was NULL.");
+            qDebug ("Contacts widget was NULL.");
             break;
         }
 
@@ -523,17 +497,14 @@ MainWindow::initInboxWidget ()
 {
     do { // Begin cleanup block (not a loop)
         if (NULL != pInboxView) {
-            log ("Inbox widget is already active");
+            qDebug ("Inbox widget is already active");
             break;
         }
 
         // Create the contact view
         pInboxView = new GVHistory (this);
 
-        // Log and status
-        QObject::connect (
-            pInboxView, SIGNAL (log(const QString &, int)),
-            this      , SLOT   (log(const QString &, int)));
+        // Status
         QObject::connect (
             pInboxView, SIGNAL (status   (const QString &, int)),
             this      , SLOT   (setStatus(const QString &, int)));
@@ -565,7 +536,7 @@ MainWindow::deinitInboxWidget ()
 {
     do { // Begin cleanup block (not a loop)
         if (NULL == pInboxView) {
-            log ("Inbox widget was NULL.");
+            qWarning ("Inbox widget was NULL.");
             break;
         }
 
@@ -671,7 +642,7 @@ MainWindow::callWithContactInfo (const GVContactInfo &info, bool bSaveIt)
     }
     else
     {
-        log ("Got contact info from cached location");
+        qDebug ("Got contact info from cached location");
     }
 
     DlgSelectContactNumber dlg(info, this);
@@ -680,13 +651,13 @@ MainWindow::callWithContactInfo (const GVContactInfo &info, bool bSaveIt)
     {
         if (QDialog::Accepted != rv)
         {
-            log ("User canceled call", 3);
+            qWarning ("User canceled call");
             break;
         }
         rv = dlg.getSelection ();
         if (-1 == rv)
         {
-            log ("Invalid selection", 3);
+            qWarning ("Invalid selection");
             break;
         }
 
@@ -814,7 +785,7 @@ MainWindow::dialAccessNumber (const QString  &strAccessNumber,
 
         if (NULL == ctx->ci)
         {
-            log ("Invalid call out initiator", 3);
+            qWarning ("Invalid call out initiator");
             setStatus ("Callout failed");
             break;
         }
@@ -881,7 +852,7 @@ MainWindow::sendTextToContact (const GVContactInfo &info, bool bSaveIt)
     }
     else
     {
-        log ("Got contact info from cached location");
+        qDebug ("Got contact info from cached location");
     }
 
     DlgSelectContactNumber dlg(info, this);
@@ -890,13 +861,13 @@ MainWindow::sendTextToContact (const GVContactInfo &info, bool bSaveIt)
     {
         if (QDialog::Accepted != rv)
         {
-            log ("User canceled SMS", 3);
+            qWarning ("User canceled SMS");
             break;
         }
         rv = dlg.getSelection ();
         if (-1 == rv)
         {
-            log ("Invalid selection", 3);
+            qWarning ("Invalid selection");
             break;
         }
 
@@ -941,7 +912,7 @@ MainWindow::sendSMS (const QStringList &arrNumbers, const QString &strText)
         {
             arrFailed += arrNumbers[i];
             msg = QString ("Failed to send an SMS to %1").arg (arrNumbers[i]);
-            log (msg, 3);
+            qWarning () << msg;
             break;
         }
     } // loop through all the numbers
@@ -1036,7 +1007,7 @@ MainWindow::refreshRegisteredNumbers ()
     do { // Begin cleanup block (not a loop)
         if (!bLoggedIn)
         {
-            log ("Not logged in. Will not refresh registered numbers.");
+            qWarning ("Not logged in. Will not refresh registered numbers.");
             break;
         }
 
@@ -1056,7 +1027,7 @@ MainWindow::refreshRegisteredNumbers ()
                     SIGNAL (registeredPhone    (const GVRegisteredNumber &)),
                  this   ,
                     SLOT   (gotRegisteredPhone (const GVRegisteredNumber &)));
-            emit log ("Failed to retrieve registered contacts!!", 3);
+            qWarning ("Failed to retrieve registered contacts!!");
             break;
         }
 
@@ -1072,7 +1043,7 @@ MainWindow::gotRegisteredPhone (const GVRegisteredNumber &info)
     QString msg = QString("\"%1\"=\"%2\"")
                     .arg (info.strDisplayName)
                     .arg (info.strNumber);
-    emit log (msg);
+    qDebug () << msg;
 
     arrNumbers += info;
 }//MainWindow::gotRegisteredPhone
@@ -1168,7 +1139,7 @@ MainWindow::getDialSettings (bool                 &bDialout   ,
             QVariant var = ui->cbDialMethod->itemData (index);
             if ((!var.isValid ()) || (var.isNull ()))
             {
-                emit log ("Invalid variant in callout numbers");
+                qWarning ("Invalid variant in callout numbers");
                 break;
             }
             initiator = (CalloutInitiator *) var.value<void *> ();
@@ -1200,7 +1171,7 @@ MainWindow::retrieveVoicemail (const QString &strVmailLink)
         QTemporaryFile tempFile (strTemplate);
         if (!tempFile.open ())
         {
-            log ("Failed to get a temp file name");
+            qWarning ("Failed to get a temp file name");
             break;
         }
         QString strTemp = QFileInfo (tempFile.fileName ()).absoluteFilePath ();
@@ -1212,7 +1183,7 @@ MainWindow::retrieveVoicemail (const QString &strVmailLink)
         if (!webPage.enqueueWork (GVAW_playVmail, l, this,
                 SLOT (onVmailDownloaded (bool, const QVariantList &))))
         {
-            log ("Failed to play Voice mail", 3);
+            qWarning ("Failed to play Voice mail");
             break;
         }
     } while (0); // End cleanup block (not a loop)
@@ -1251,9 +1222,23 @@ MainWindow::playVmail (const QString &strFile)
 {
     VMailDialog *dlgVmail = new VMailDialog (this);
     dlgVmail->setAttribute (Qt::WA_DeleteOnClose);
-    QObject::connect (dlgVmail, SIGNAL (log (const QString &, int)),
-                      this    , SLOT   (log (const QString &, int)));
     QObject::connect (dlgVmail, SIGNAL (status (const QString &, int)),
                       this    , SLOT   (setStatus (const QString &, int)));
     dlgVmail->play (strFile);
 }//MainWindow::playVmail
+
+void
+MainWindow::on_actionWeb_view_triggered ()
+{
+    if (pWebWidget->isVisible ()) {
+        pWebWidget->hide ();
+    } else {
+        pWebWidget->show ();
+    }
+}//MainWindow::on_actionWeb_view_triggered
+
+void
+MainWindow::on_actionLogs_triggered ()
+{
+    //
+}//MainWindow::on_actionLogs_triggered
